"""
This type stub file was generated by pyright.
"""

"""
Low-level text helper utilities.
"""
LayoutItem = ...
def warn_on_missing_glyph(codepoint): # -> None:
    ...

def layout(string, font, *, kern_mode=...): # -> Generator[Any, Any, None]:
    """
    Render *string* with *font*.  For each character in *string*, yield a
    (glyph-index, x-position) pair.  When such a pair is yielded, the font's
    glyph is set to the corresponding character.

    Parameters
    ----------
    string : str
        The string to be rendered.
    font : FT2Font
        The font.
    kern_mode : int
        A FreeType kerning mode.

    Yields
    ------
    glyph_index : int
    x_position : float
    """
    ...

